abacusai.custom_metric — AbacusAI documentation

# abacusai.custom_metric

## Classes

`CustomMetric` | Custom metric.

## Module Contents

class abacusai.custom_metric.CustomMetric(client, customMetricId=None, name=None, createdAt=None, problemType=None, notebookId=None, latestCustomMetricVersion={})

  Bases: `abacusai.return_class.AbstractApiClass`

  Custom metric.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - customMetricId (str) – Unique string identifier of the custom metric.

    - name (str) – Name assigned to the custom metric.

    - createdAt (str) – Date and time when the custom metric was created (ISO 8601 format).

    - problemType (str) – Problem type that this custom metric is applicable to (e.g. regression).

    - notebookId (str) – Unique string identifier of the notebook used to create/edit the custom metric.

    - latestCustomMetricVersion (CustomMetricVersion) – Latest version of the custom metric.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict